##  [](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointSnapshots)Snapshot all environment(endpoint)
Snapshot all environments(endpoints) **Access policy** : administrator
##### Authorizations:
_ApiKeyAuth_ _jwt_
### Responses
**204**
Success
**500**
Server Error
post/endpoints/snapshot
https://api-docs.portainer.io/api/endpoints/snapshot
